==> payara-embedded-web-4.1.2.172-sources.jar: fish/payara/nucleus/notification/log/LogNotificationEventFactory.java <==
/*
 *
 * Copyright (c) 2016 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.nucleus.notification.log;

import fish.payara.nucleus.notification.configuration.NotifierType;
import fish.payara.nucleus.notification.domain.EventSource;
import fish.payara.nucleus.notification.domain.NotificationEventFactory;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.hk2.runlevel.RunLevel;
import org.jvnet.hk2.annotations.Service;

import javax.annotation.PostConstruct;
import java.util.logging.Level;

/**
 * @author mertcaliskan
 */
@Service
@RunLevel(StartupRunLevel.VAL)
public class LogNotificationEventFactory extends NotificationEventFactory<LogNotificationEvent> {

    @PostConstruct
    void postConstruct() {
        registerEventFactory(NotifierType.LOG, this);
    }

    public LogNotificationEvent buildNotificationEvent(String subject, String message) {
        LogNotificationEvent event = initializeEvent(new LogNotificationEvent());
        event.setSubject(subject);
        event.setLevel(Level.INFO);
        event.setMessage(message);

        return event;
    }

    @Override
    public LogNotificationEvent buildNotificationEvent(Level level, String subject, String message, Object[] parameters) {
        LogNotificationEvent notificationEvent = initializeEvent(new LogNotificationEvent());
        notificationEvent.setLevel(level);
        notificationEvent.setSubject(subject);
        notificationEvent.setMessage(message);
        notificationEvent.setParameters(parameters);

        return notificationEvent;
    }
}

==> payara-embedded-web-5.192-sources.jar: fish/payara/nucleus/notification/log/LogNotificationEventFactory.java <==
/*
 *
 * Copyright (c) 2016-2018 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.nucleus.notification.log;

import fish.payara.notification.healthcheck.HealthCheckResultEntry;
import fish.payara.notification.requesttracing.RequestTrace;
import fish.payara.nucleus.notification.configuration.NotifierType;
import fish.payara.nucleus.notification.domain.NotificationEventFactory;
import org.glassfish.api.StartupRunLevel;
import org.glassfish.hk2.runlevel.RunLevel;
import org.jvnet.hk2.annotations.Service;

import javax.annotation.PostConstruct;
import java.util.List;
import java.util.logging.Level;

/**
 * Factory to build events for {@link LogNotifier}
 * @author mertcaliskan
 */
@Service
@RunLevel(StartupRunLevel.VAL)
public class LogNotificationEventFactory extends NotificationEventFactory<LogNotificationEvent> {

    @PostConstruct
    void postConstruct() {
        registerEventFactory(NotifierType.LOG, this);
    }

    @Override
    protected LogNotificationEvent createEventInstance() {
        return new LogNotificationEvent();
    }

    @Override
    public LogNotificationEvent buildNotificationEvent(String subject, RequestTrace requestTrace) {
        LogNotificationEvent event = initializeEvent(createEventInstance());
        event.setSubject(subject);
        event.setLevel(Level.INFO);
        event.setMessage(requestTrace.toString());

        return event;
    }
    
    
    @Override
    public LogNotificationEvent buildNotificationEvent(String subject, String message) {
        LogNotificationEvent event = super.buildNotificationEvent(subject, message);
        event.setLevel(Level.INFO);
        return event;
    }

    @Override
    public LogNotificationEvent buildNotificationEvent(String name, List<HealthCheckResultEntry> entries, Level level) {
        LogNotificationEvent notificationEvent = initializeEvent(createEventInstance());
        notificationEvent.setLevel(level);
        notificationEvent.setSubject(getSubject(level));
        notificationEvent.setMessage("{0}:{1}");
        Object[] parameters = {name, getCumulativeMessages(entries)};
        notificationEvent.setParameters(parameters);

        return notificationEvent;
    }

    @Override
    public LogNotificationEvent buildNotificationEvent(Level level, String subject, String message, Object[] parameters) {
        LogNotificationEvent event = super.buildNotificationEvent(level, subject, message, parameters);
        event.setLevel(level);
        return event;
    }
}
